aboutsummaryrefslogtreecommitdiff
path: root/pw_software_update/public/pw_software_update/bundled_update_backend.h
diff options
context:
space:
mode:
Diffstat (limited to 'pw_software_update/public/pw_software_update/bundled_update_backend.h')
-rw-r--r--pw_software_update/public/pw_software_update/bundled_update_backend.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/pw_software_update/public/pw_software_update/bundled_update_backend.h b/pw_software_update/public/pw_software_update/bundled_update_backend.h
index c6685d5ac..03e46992c 100644
--- a/pw_software_update/public/pw_software_update/bundled_update_backend.h
+++ b/pw_software_update/public/pw_software_update/bundled_update_backend.h
@@ -25,7 +25,7 @@
namespace pw::software_update {
-// TODO(b/235273688): update documentation for backend api contract
+// TODO: b/235273688 - update documentation for backend api contract
class BundledUpdateBackend {
public:
virtual ~BundledUpdateBackend() = default;
@@ -85,9 +85,9 @@ class BundledUpdateBackend {
// handed over to update backend.
virtual int64_t GetStatus() { return 0; }
// Update the specific target file on the device.
virtual Status ApplyTargetFile(std::string_view target_file_name,
- stream::Reader& target_payload,
+ stream::SeekableReader& target_payload,
size_t update_bundle_offset) = 0;
// Backend to probe the device manifest and prepare a ready-to-go reader
@@ -85,9 +85,9 @@ class BundledUpdateBackend {
// handed over to update backend.
virtual int64_t GetStatus() { return 0; }
- // Update the specific target file on the device.
+ // Update the specific target file on the device, using seekable reader.
virtual Status ApplyTargetFile(std::string_view target_file_name,